@@ -241,24 +241,3 @@ pseudo_stat_msg(PSEUDO_STATBUF *buf, const pseudo_msg_t *msg) {
 	buf->st_mode = msg->mode;
 	buf->st_rdev = msg->rdev;
 }
-
-#if PSEUDO_STATBUF_64
-void
-pseudo_msg_stat_plain(pseudo_msg_t *msg, const struct stat *buf) {
-	PSEUDO_STATBUF buf64;
-	if (buf) {
-		pseudo_stat64_from32(&buf64, buf);
-		pseudo_msg_stat(msg, &buf64);
-	}
-}
-
-void
-pseudo_stat_msg_plain(struct stat *buf, const pseudo_msg_t *msg) {
-	PSEUDO_STATBUF buf64;
-	if (buf) {
-		pseudo_stat64_from32(&buf64, buf);
-		pseudo_stat_msg(&buf64, msg);
-		pseudo_stat32_from64(buf, &buf64);
-	}
-}
-#endif
